package goap

// JsonLD fields
const (
	KEY_ID    = "@id"    // Value of type string
	KEY_TYPE  = "@type"  // Value of type string slice / activitystreams object url slice
	KEY_VALUE = "@value" // Could be any type really
)

// Mastodon fields
const (
	KEY_MASTO_DEVICES       = "http://joinmastodon.org/ns#devices"      // No idea what this is, but Masto includes it
	KEY_MASTO_DISCOVERABLE  = "http://joinmastodon.org/ns#discoverable" // iirc this is whether the object can be found by crawlers
	KEY_MASTO_FEATURED      = "http://joinmastodon.org/ns#featured"     // Users tagged? I think
	KEY_MASTO_FEATURED_TAGS = "http://joinmastodon.org/ns#featuredTags" // Hashtags included, I think
	KEY_MASTO_INDEXABLE     = "http://joinmastodon.org/ns#indexable"    // Is the object crawlable round 2
	KEY_MASTO_MEMORIAL      = "http://joinmastodon.org/ns#memorial"     // Account dead and disabled?

	KEY_MASTO_EMOJI = "http://joinmastodon.org/ns#Emoji" // Object is an emoji
)

// Generic W3 fields
const (
	KEY_W3_INBOX                 = "http://www.w3.org/ns/ldp#inbox"          // Where to send activities to
	KEY_W3_SECURITY_OWNER        = "https://w3id.org/security#owner"         // Owner of the public key
	KEY_W3_SECURITY_PUBLICKEY    = "https://w3id.org/security#publicKey"     // Public key of the account
	KEY_W3_SECURITY_PUBLICKEYPEM = "https://w3id.org/security#publicKeyPem"  // Pem content of the key
	KEY_W3_VCARD_ADDRESS         = "http://www.w3.org/2006/vcard/ns#Address" // Vcard address of an account
	KEY_W3_VCARD_BIRTHDAY        = "http://www.w3.org/2006/vcard/ns#bday"    // Vcard birthday of an account

)

// Generic W3 object type
const (
	KEY_W3_SECURITY_KEY = "https://w3id.org/security#Key" // Object is a PublicKey
)

// W3 Activitystreams fields
const (
	KEY_ACTIVITYSTREAMS_ACTOR             = "https://www.w3.org/ns/activitystreams#actor"
	KEY_ACTIVITYSTREAMS_ALSOKNOWNAS       = "https://www.w3.org/ns/activitystreams#alsoKnownAs"               // Lists of usernames?
	KEY_ACTIVITYSTREAMS_ATTACHMENTS       = "https://www.w3.org/ns/activitystreams#attachment"                // Attached elements like emotes and hashtags
	KEY_ACTIVITYSTREAMS_ATTRIBUTEDTO      = "https://www.w3.org/ns/activitystreams#attributedTo"              // Creator of object?
	KEY_ACTIVITYSTREAMS_CC                = "https://www.w3.org/ns/activitystreams#cc"                        // Urls also included in the object
	KEY_ACTIVITYSTREAMS_CONTENT           = "https://www.w3.org/ns/activitystreams#content"                   // (String) content of an object
	KEY_ACTIVITYSTREAMS_ENDPOINTS         = "https://www.w3.org/ns/activitystreams#endpoints"                 // list of assocciated endpoints
	KEY_ACTIVITYSTREAMS_FOLLOWERS         = "https://www.w3.org/ns/activitystreams#followers"                 // Who is following the account
	KEY_ACTIVITYSTREAMS_FOLLOWING         = "https://www.w3.org/ns/activitystreams#following"                 // Who is this account following
	KEY_ACTIVITYSTREAMS_HREF              = "https://www.w3.org/ns/activitystreams#href"                      // Some url with id
	KEY_ACTIVITYSTREAMS_ICON              = "https://www.w3.org/ns/activitystreams#icon"                      // User icon
	KEY_ACTIVITYSTREAMS_IMAGE_ATTRIBUTE   = "https://www.w3.org/ns/activitystreams#image"                     // Account banner
	KEY_ACTIVITYSTREAMS_MEDIATYPE         = "https://www.w3.org/ns/activitystreams#mediaType"                 // What type of media is this? Example image/jpeg
	KEY_ACTIVITYSTREAMS_NAME              = "https://www.w3.org/ns/activitystreams#name"                      // Name of the object
	KEY_ACTIVITYSTREAMS_OUTBOX            = "https://www.w3.org/ns/activitystreams#outbox"                    // Link to the account's outbox
	KEY_ACTIVITYSTREAMS_OBJECT            = "https://www.w3.org/ns/activitystreams#object"                    // Object url and sometimes value
	KEY_ACTIVITYSTREAMS_PREFFEREDUSERNAME = "https://www.w3.org/ns/activitystreams#preferredUsername"         // What the shown username is
	KEY_ACTIVITYSTREAMS_PUBLISHED         = "https://www.w3.org/ns/activitystreams#published"                 // When an object was created
	KEY_ACTIVITYSTREAMS_RESTRICTED_FOLLOW = "https://www.w3.org/ns/activitystreams#manuallyApprovesFollowers" // Does the account manually approve follow requests
	KEY_ACTIVITYSTREAMS_REPLIES           = "https://www.w3.org/ns/activitystreams#replies"                   // Object containing the replies. Should always be a Collection
	KEY_ACTIVITYSTREAMS_SHAREDINBOX       = "https://www.w3.org/ns/activitystreams#sharedInbox"               // Link to the shared inbox of the server
	KEY_ACTIVITYSTREAMS_SUMMARY           = "https://www.w3.org/ns/activitystreams#summary"                   // Summary of an account or the cw of a note
	KEY_ACTIVITYSTREAMS_SENSITIVE         = "https://www.w3.org/ns/activitystreams#sensitive"                 // Whether the content of the object is marked as sensitive
	KEY_ACTIVITYSTREAMS_TAG               = "https://www.w3.org/ns/activitystreams#tag"                       // A tag, usually hashtags included somewhere
	KEY_ACTIVITYSTREAMS_TO                = "https://www.w3.org/ns/activitystreams#to"                        // Urls to send an activity to
	KEY_ACTIVITYSTREAMS_URL               = "https://www.w3.org/ns/activitystreams#url"                       // Some url
	KEY_ACTIVITYSTREAMS_UPDATED           = "https://www.w3.org/ns/activitystreams#updated"                   // When the content was last updated
	KEY_ACTIVITYSTREAMS_INREPLYTO         = "https://www.w3.org/ns/activitystreams#inReplyTo"                 // What the object is replying to
	KEY_ACTIVITYSTREAMS_QUOTEURL          = "https://www.w3.org/ns/activitystreams#quoteUrl"                  // Url to the object being quoted
)

// W3 Activitystreams object types
const (
	// Object types (I think)
	// Those are values the object type can have

	KEY_ACTIVITYSTREAMS_FOLLOW         = "https://www.w3.org/ns/activitystreams#Follow"         // Object is an activity of type follow
	KEY_ACTIVITYSTREAMS_PERSON         = "https://www.w3.org/ns/activitystreams#Person"         // Object is of type Person
	KEY_ACTIVITYSTREAMS_CREATE         = "https://www.w3.org/ns/activitystreams#Create"         // Object is an activity of type Create
	KEY_ACTIVITYSTREAMS_COLLECTION     = "https://www.w3.org/ns/activitystreams#Collection"     // Object is a collection of things
	KEY_ACTIVITYSTREAMS_COLLECTIONPAGE = "https://www.w3.org/ns/activitystreams#CollectionPage" // Object is a page of a collection
	KEY_ACTIVITYSTREAMS_HASHTAG        = "https://www.w3.org/ns/activitystreams#Hashtag"        // Object is a hashtag
	KEY_ACTIVITYSTREAMS_LIKE           = "https://www.w3.org/ns/activitystreams#Like"           // Object is an activity of type like
	KEY_ACTIVITYSTREAMS_NOTE           = "https://www.w3.org/ns/activitystreams#Note"           // Object is of type Note
	KEY_ACTIVITYSTREAMS_IMAGE_TYPE     = "https://www.w3.org/ns/activitystreams#Image"          // Object is of type Image
	KEY_ACTIVITYSTREAMS_MENTION        = "https://www.w3.org/ns/activitystreams#Mention"        // Object is of type Mention

	// Collection things
	KEY_ACTIVITYSTREAMS_FIRST  = "https://www.w3.org/ns/activitystreams#first"  // First page in a collection
	KEY_ACTIVITYSTREAMS_ITEMS  = "https://www.w3.org/ns/activitystreams#items"  // Items in this collection page
	KEY_ACTIVITYSTREAMS_NEXT   = "https://www.w3.org/ns/activitystreams#next"   // Next page in a collection
	KEY_ACTIVITYSTREAMS_PARTOF = "https://www.w3.org/ns/activitystreams#partOf" // Collection the current page is a part of
)

// W3 Activitystreams unknown
const (
	// Misc
	KEY_ACTIVITYSTREAMS_OAUTHAUTHORIZATION = "https://www.w3.org/ns/activitystreams#oauthAuthorizationEndpoint" // Endpoint url for oauth login?
	KEY_ACTIVITYSTREAMS_OAUTHTOKEN         = "https://www.w3.org/ns/activitystreams#oauthTokenEndpoint"         // Endpoint url for oauth token verification?
	KEY_ACTIVITYSTREAMS_UPLOADMEDIA        = "https://www.w3.org/ns/activitystreams#uploadMedia"                // Endpoint url to upload media to?
	KEY_ACTIVITYSTREAMS_PUBLIC             = "https://www.w3.org/ns/activitystreams#Public"                     // Note target
)

// schema fields
const (
	KEY_SCHEMA_VALUE = "http://schema.org#value" // The value for some field

	KEY_SCHEMA_PROPERTYVALUE = "http://schema.org#PropertyValue" // Object is of type property value
)

// Misskey and fork fields
const (
	KEY_MISSKEY_MKSUMMARY   = "https://misskey-hub.net/ns#_misskey_summary" // Misskey specific formatted summary
	KEY_MISSKEY_ISCAT       = "https://misskey-hub.net/ns#isCat"            // Does the account identify as cat?
	KEY_MISSKEY_MKQUOTE     = "https://misskey-hub.net/ns#_misskey_quote"   // Misskey specific quote field
	KEY_FIREFISH_SPEAKASCAT = "https://joinfirefish.org/ns#speakAsCat"      // Does the account speak like a cat?
)

// No idea what either of those two do or are used for

// Litepub fields
const (
	KEY_LITEPUB_CAPABILITIES      = "http://litepub.social/ns#capabilities"
	KEY_LITEPUB_OAUTHREGISTRATION = "http://litepub.social/ns#oauthRegistrationEndpoint"
)

// W3 XML fields
const (
	KEY_XMLSCHEMA_DATETIME = "http://www.w3.org/2001/XMLSchema#dateTime" // Type value for published value field
)

// Ostatus fields
//
// NOTE: ostatus.org seems to be redirecting to some weird scam(?) page
const (
	KEY_OSTATUS_ATOMURI          = "http://ostatus.org#atomUri"          // Same as @id I think
	KEY_OSTATUS_CONVERSATION     = "http://ostatus.org#conversation"     // Similar to inReplyTo
	KEY_OSTATUS_INREPLYTOATOMURI = "http://ostatus.org#inReplyToAtomUri" // Same as InReplyTo, but with an atom uri as target
)

// Unknown origin fields
const (
	KEY_MYSTERIOUS_NOINDEX       = "_:noindex"
	KEY_MYSTERIOUS_BACKGROUNDURL = "_:backgroundUrl"
	KEY_MYSTERIOUS_FEATURED      = "_:featured"
)

// Fedibird fields
const (
	KEY_FEDIBIRD_QUOTEURI = "http://fedibird.com/ns#quoteUri"
)
